==> java-client-8.2.0-sources.jar: com/urbanairship/api/reports/parse/ResponseReportResponseDeserializer.java <==
package com.urbanairship.api.reports.parse;

import com.fasterxml.jackson.databind.JsonDeserializer;
import com.fasterxml.jackson.core.JsonParser;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.google.common.collect.ImmutableMap;
import com.google.common.base.Supplier;
import com.urbanairship.api.common.parse.FieldParser;
import com.urbanairship.api.common.parse.FieldParserRegistry;
import com.urbanairship.api.common.parse.MapFieldParserRegistry;
import com.urbanairship.api.common.parse.StandardObjectDeserializer;
import com.urbanairship.api.reports.model.ResponseReportResponse;

import java.io.IOException;

public class ResponseReportResponseDeserializer extends JsonDeserializer<ResponseReportResponse> {
    private static final FieldParserRegistry<ResponseReportResponse, ResponseReportResponseReader> FIELD_PARSERS =
            new MapFieldParserRegistry<ResponseReportResponse, ResponseReportResponseReader>(
                    ImmutableMap.<String, FieldParser<ResponseReportResponseReader>>builder()
                            .put("android", new FieldParser<ResponseReportResponseReader>() {
                                @Override
                                public void parse(ResponseReportResponseReader reader, JsonParser jsonParser, DeserializationContext deserializationContext) throws IOException {
                                    reader.readDeviceStats(jsonParser, "android");
                                }
                            })
                            .put("date", new FieldParser<ResponseReportResponseReader>() {
                                @Override
                                public void parse(ResponseReportResponseReader reader,
                                                  JsonParser jsonParser,
                                                  DeserializationContext deserializationContext) throws IOException {
                                    reader.readDate(jsonParser);
                                }
                            })
                            .put("ios", new FieldParser<ResponseReportResponseReader>() {
                                @Override
                                public void parse(ResponseReportResponseReader reader, JsonParser jsonParser, DeserializationContext deserializationContext) throws IOException {
                                    reader.readDeviceStats(jsonParser, "ios");
                                }
                            })
                            .build()
            );

    private final StandardObjectDeserializer<ResponseReportResponse, ?> deserializer;

    public ResponseReportResponseDeserializer() {
        deserializer = new StandardObjectDeserializer<ResponseReportResponse, ResponseReportResponseReader>(
                FIELD_PARSERS,
                new Supplier<ResponseReportResponseReader>() {
                    @Override
                    public ResponseReportResponseReader get() {
                        return new ResponseReportResponseReader();
                    }
                }
        );
    }

    public ResponseReportResponse deserialize(JsonParser jsonParser, DeserializationContext deserializationContext) throws IOException {
        return deserializer.deserialize(jsonParser, deserializationContext);
    }
}

==> java-client-9.1.1-sources.jar: com/urbanairship/api/reports/parse/ResponseReportResponseDeserializer.java <==
package com.urbanairship.api.reports.parse;

import com.fasterxml.jackson.core.JsonParser;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.JsonDeserializer;
import com.google.common.base.Supplier;
import com.google.common.collect.ImmutableMap;
import com.urbanairship.api.common.parse.FieldParser;
import com.urbanairship.api.common.parse.FieldParserRegistry;
import com.urbanairship.api.common.parse.MapFieldParserRegistry;
import com.urbanairship.api.common.parse.StandardObjectDeserializer;
import com.urbanairship.api.reports.model.ResponseReportResponse;

import java.io.IOException;

public class ResponseReportResponseDeserializer extends JsonDeserializer<ResponseReportResponse> {
    private static final FieldParserRegistry<ResponseReportResponse, ResponseReportResponseReader> FIELD_PARSERS =
            new MapFieldParserRegistry<ResponseReportResponse, ResponseReportResponseReader>(
                    ImmutableMap.<String, FieldParser<ResponseReportResponseReader>>builder()
                            .put("android", (reader, jsonParser, deserializationContext) -> reader.readDeviceStats(jsonParser, "android"))
                            .put("date", (reader, jsonParser, deserializationContext) -> reader.readDate(jsonParser))
                            .put("ios", (reader, jsonParser, deserializationContext) -> reader.readDeviceStats(jsonParser, "ios"))
                            .build()
            );

    private final StandardObjectDeserializer<ResponseReportResponse, ?> deserializer;

    public ResponseReportResponseDeserializer() {
        deserializer = new StandardObjectDeserializer<ResponseReportResponse, ResponseReportResponseReader>(
                FIELD_PARSERS,
                () -> new ResponseReportResponseReader()
        );
    }

    public ResponseReportResponse deserialize(JsonParser jsonParser, DeserializationContext deserializationContext) throws IOException {
        return deserializer.deserialize(jsonParser, deserializationContext);
    }
}
